@@ -2,6 +2,7 @@ from files_sdk.models.account_line_item import AccountLineItem
 from files_sdk.models.action import Action
 from files_sdk.models.action_notification_export import ActionNotificationExport
 from files_sdk.models.action_notification_export_result import ActionNotificationExportResult
+from files_sdk.models.action_webhook_failure import ActionWebhookFailure
 from files_sdk.models.api_key import ApiKey
 from files_sdk.models.app import App
 from files_sdk.models.as2_key import As2Key
@@ -21,6 +22,7 @@ from files_sdk.models.file import File
 from files_sdk.models.file_action import FileAction
 from files_sdk.models.file_comment import FileComment
 from files_sdk.models.file_comment_reaction import FileCommentReaction
+from files_sdk.models.file_migration import FileMigration
 from files_sdk.models.file_upload_part import FileUploadPart
 from files_sdk.models.folder import Folder
 from files_sdk.models.form_field import FormField
